import { BearMetalStore } from "@bearmetal/store";
import { getPackVersion } from "../util/packVersion.ts";
import type { Router } from "../router.ts";
import { getTagDir } from "./getTagDir.ts";

export const createTagRoutes = (router: Router) => {
  router.route("/api/pack/:namespace/tags")
    .get(async (_, ctx) => {
      if (!ctx.params.namespace) {
        return new Response("somehow hit the tags endpoint without namespace", {
          status: 500,
        });
      }
      using store = new BearMetalStore();

      const version = getPackVersion(store);

      const tagDir = await getTagDir(store, ctx.params.namespace, version);

      try {
        const tags = Array.from(
          Deno.readDirSync(
            tagDir,
          ),
        );
        return new Response(JSON.stringify(tags), { status: 200 });
      } catch {
        return new Response("no tags found", { status: 404 });
      }
    });
};
